<?php

/**
 * @file
 * Configuration options for the MyFantasyLeague module.
 */

/**
 * Configuration options for the MyFantasyLeague module.
 */
function myfantasyleague_config() {
  // Get the standings columns from the database.
  $columns = myfantasyleague_standings_columns();

  $form['#tree'] = TRUE;
  $form['league_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Your MyFantasyLeague League ID'),
    '#default_value' => variable_get('myfantasyleague_league_id', NULL),
    '#description' => t('To find your league ID, go to your league home page and look at the URL: http://www.myfantasyleague.com/2011/home/xxxxx. The \'xxxxx\' part is your league ID.'),
  );
  $form['year'] = array(
    '#type' => 'textfield',
    '#title' => t('Your MyFantasyLeague League Year'),
    '#default_value' => variable_get('myfantasyleague_year', NULL),
    '#description' => '',
  );
  $form['columns_title'] = array(
    '#type' => 'item',
    '#title' => t('Standings Columns Order'),
  );
  foreach ($columns as $id => $column) {
    $form['columns'][$id]['name'] = array('#value' => $column->name);
    $form['columns'][$id]['weight'] = array(
      '#type' => 'weight',
      '#delta' => 50,
      '#default_value' => $column->weight,
    );
    $form['columns'][$id]['status'] = array(
      '#type' => 'checkbox',
      '#default_value' => $column->status,
    );
  }
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Submit',
  );

  return $form;
}

/**
 * MyFantasyLeague configuration validator.
 */
function myfantasyleague_config_validate($form, &$form_state) {
  if (!is_numeric($form['league_id']['#value'])) {
    form_error($form['league_id'], t('The League ID must be numeric!'));
  }
  if (!is_numeric($form['year']['#value'])) {
    form_error($form['year'], t('The year must be numeric!'));
  }
}

/**
 * MyFantasyLeague configuration submit handler.
 */
function myfantasyleague_config_submit($form, &$form_state) {
  // Update standings columns weights and status.
  foreach ($form_state['values']['columns'] as $id => $data) {
    if (is_array($data) && isset($data['weight']) && isset($data['status'])) {
      db_query(
        "UPDATE {myfantasyleague_standings_columns} "
        . "SET weight = %d, status = %d "
        . "WHERE name = '%s'",
        $data['weight'],
        $data['status'],
        $id
      );
    }
  }

  // Set the form information into variables.
  variable_set('myfantasyleague_league_id', $form['league_id']['#value']);
  variable_set('myfantasyleague_year', $form['year']['#value']);

  // Clear all cached data from this module since league info might have changed.
  cache_clear_all('myfantasyleague', 'cache', TRUE);

  drupal_set_message(t('Saved changes.'));
}

/**
 * Returns HTML for the MyFantasyLeague configuration form.
 *
 * @param $variables
 *   An associative array containing the form: A render element representing the form.
 *
 * @ingroup themeable
 */
function theme_myfantasyleague_config($variables) {
  $rows = array();
  foreach (element_children($variables['columns']) as $id) {
    $variables['columns'][$id]['weight']['#attributes']['class'] = 'myfantasyleague-standings-columns-order-weight';
    $rows[] = array(
      'data' => array(
        drupal_render($variables['columns'][$id]['name']),
        drupal_render($variables['columns'][$id]['weight']),
        array('data' => drupal_render($variables['columns'][$id]['status']), 'class' => 'checkbox'),
      ),
      'class' => 'draggable',
    );
  }
  $header = array(t('Name'), t('Weight'), array('data' => t('Enabled'), 'class' => 'checkbox'));
  $output = drupal_render($variables['league_id']);
  $output .= drupal_render($variables['year']);
  $output .= drupal_render($variables['columns_title']);
  $output .= theme('table', $header, $rows, array('id' => 'myfantasyleague-standings-columns-order'));
  $output .= drupal_render($variables);

  drupal_add_tabledrag('myfantasyleague-standings-columns-order', 'order', 'sibling', 'myfantasyleague-standings-columns-order-weight');

  return $output;
}